

assym_alpha <- function(sfs_neutral, sfs_functional, lower = 0.1, plot = TRUE, add = FALSE, col = "black", modelCol = "red", ylim = c(-0.5,0.5), pch = 19){
    #we assume the sfs has counts from zero to n.
    n = length(sfs_neutral) - 1
    alpha_x <- 1 - ((sfs_neutral[n+1] / sfs_functional[n+1]) * (sfs_functional[2:n] / sfs_neutral[2:n]))
    
    first = which(1:n/n >= lower)[1]
    
    x <- (first:n-1)/n

    y <- alpha_x[first:n-1]
        
    model <- nls(y ~ SSasymp(x, a, b, c))

    xv = rev(seq(1,lower,-0.01))

    y_pred <- predict(model,list(x=xv))

    assym <- y_pred[length(xv)]
    
    if (plot == TRUE){

        if (add == F){
        
            plot(0, cex = 0, ylim = ylim, xlim = c(0,1), bty = "L", ylab = expression(paste(alpha, "(x)")), xlab = "Derived Allele Frequency (x)")

            abline(h = seq(-1,1,0.1), col = "gray85", lty = 3)
            abline(v = seq(0,1,0.1), col = "gray85", lty = 3)
            }
        
        points(x, y, col = col, pch = pch)

            
        lines(xv, y_pred, col = modelCol)

        abline(h = assym, col = modelCol, lty = 2)

        #text(0.1, assym+0.02, labels = round(assym,3), col = modelCol)
        }
    
    return(assym)
    }




westCol = "#FB8072"
eastCol = "#8DD3C7"





################################################################################################################################


syn_genes_sfs_west_A <- read.csv("data/sfs/set80.Zupdated.realign80.GQ30.syn.HWE05.autoscafs.west.sample16.eraOut.genes.sfs.csv", as.is = T)
non_genes_sfs_west_A <- read.csv("data/sfs/set80.Zupdated.realign80.GQ30.non.HWE05.autoscafs.west.sample16.eraOut.genes.sfs.csv", as.is = T)

syn_genes_sfs_west_Z <- read.csv("data/sfs/set80.Zupdated.realign80.GQ30.syn.HWE05.chrZscafs.west.sample16M.eraOut.genes.sfs.csv", as.is = T)
non_genes_sfs_west_Z <- read.csv("data/sfs/set80.Zupdated.realign80.GQ30.non.HWE05.chrZscafs.west.sample16M.eraOut.genes.sfs.csv", as.is = T)

nGenes = ncol(syn_genes_sfs_west_A) - 1

syn_genes_sites <- syn_genes_sfs_west_A[,2:(nGenes+1)] + syn_genes_sfs_west_Z[,2:(nGenes+1)]
non_genes_sites <- non_genes_sfs_west_A[,2:(nGenes+1)] + non_genes_sfs_west_Z[,2:(nGenes+1)]


non_zero_genes <- which(apply(syn_genes_sites, 2, sum, na.rm = T) >= 1 | apply(non_genes_sites, 2, sum, na.rm = T) >= 1)


sample_alpha <- function(){
    sample <- sample(non_zero_genes, replace = T)
    syn_sample_sums <- apply(syn_genes_sites[,sample], 1, sum)
    non_sample_sums <- apply(non_genes_sites[,sample], 1, sum)
    assym_alpha(syn_sample_sums,non_sample_sums, lower = 0.1, plot = F)
    }


bs_alphas <- sapply(1:1000, function(x){sample_alpha()})

q5 <- quantile(bs_alphas, .05)
q95 <- quantile(bs_alphas, .95)



##

syn_genes_sum <- apply(syn_genes_sites, 1, sum)
non_genes_sum <- apply(non_genes_sites, 1, sum)


png("Images/assymptotic_alpha_BS_s16.png", width = 2000, height = 2000, res = 300)

par(mar = c(4,4,1,1))

plot(0, cex = 0, ylim = c(-0.2,0.5), xlim = c(0,1), bty = "L", ylab = expression(paste(alpha, "(x)")), xlab = "Derived Allele Frequency (x)")
abline(h = seq(-1,1,0.1), col = "gray85", lty = 3)
abline(v = seq(0,1,0.1), col = "gray85", lty = 3)

rect(-.1,q5,1.1,q95, col = rgb(1,0,0,0.1), border = NA)

assym_alpha(syn_genes_sum,non_genes_sum, lower = 0.1, add = T)

dev.off()

